import * as i0 from '@angular/core';
import { EventEmitter, Injectable, Component, ViewChild, Input, Output, HostListener, ChangeDetectionStrategy, NgModule } from '@angular/core';
import { Subject } from 'rxjs';
import * as i1 from '@angular/common';
import { CommonModule } from '@angular/common';

let toastIdentitySequence = 0;
class Toast {
    constructor(message, type) {
        this.message = message;
        this.type = type;
        this.time = new Date().getTime();
        this.id = toastIdentitySequence++;
        this.$resetToast = new Subject();
    }
}

var ToastType;
(function (ToastType) {
    ToastType[ToastType["info"] = 0] = "info";
    ToastType[ToastType["success"] = 1] = "success";
    ToastType[ToastType["warning"] = 2] = "warning";
    ToastType[ToastType["error"] = 3] = "error";
    ToastType[ToastType["default"] = 4] = "default";
})(ToastType || (ToastType = {}));

class ToastService {
    constructor() {
        this.toastAddedEvent = new EventEmitter();
        this.dismissAllEvent = new EventEmitter();
    }
    dismissAll() {
        this.dismissAllEvent.emit();
    }
    info(message) {
        const toast = new Toast(message, ToastType.info);
        this.toastAddedEvent.emit(toast);
    }
    success(message) {
        const toast = new Toast(message, ToastType.success);
        this.toastAddedEvent.emit(toast);
    }
    warn(message) {
        const toast = new Toast(message, ToastType.warning);
        this.toastAddedEvent.emit(toast);
    }
    error(message) {
        const toast = new Toast(message, ToastType.error);
        this.toastAddedEvent.emit(toast);
    }
    default(message) {
        const toast = new Toast(message, ToastType.default);
        this.toastAddedEvent.emit(toast);
    }
}
/** @nocollapse */ ToastService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.0.5", ngImport: i0, type: ToastService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
/** @nocollapse */ ToastService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "12.0.5", ngImport: i0, type: ToastService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.0.5", ngImport: i0, type: ToastService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return []; } });

class ToastifyToastComponent {
    constructor(_cd, _zone) {
        this._cd = _cd;
        this._zone = _zone;
        this.autoClose = 5000;
        this.autoCloseError = undefined;
        this.autoCloseSuccess = undefined;
        this.autoCloseInfo = undefined;
        this.autoCloseWarn = undefined;
        this.hideProgressBar = false;
        this.pauseOnHover = true;
        this.pauseOnVisibilityChange = true;
        this.closeOnClick = true;
        this.dismissEvent = new EventEmitter();
        this.ToastType = ToastType;
        this.running = false;
    }
    ngOnInit() {
        this.autoCloseRemaining = this.autoCloseAfterSpecificChange();
        this.startTime = this.toast.time;
        this.toast.$resetToast.subscribe(() => this.resetToastTimer());
        // Do not start timer when toast is prompted while window is out of focus
        if (this.handleVisibilityChange && document.visibilityState === 'visible') {
            this.startCloseTimer();
        }
        // Start progress bar animation
        this.triggerProgressBarAnimation();
    }
    triggerProgressBarAnimation() {
        // Cancel previous animlation to avoid leaks
        if (this._progressBarAnimation !== undefined) {
            cancelAnimationFrame(this._progressBarAnimation);
        }
        // Start animation
        const frame = () => {
            if (this.running) {
                const remainingTime = Math.max(0, this.expectedAutoDismissTime - new Date().getTime());
                const percentage = 100 - ((remainingTime / this.autoCloseAfterSpecificChange()) * 100);
                this.progressBarCover.nativeElement.style.width = percentage + '%';
                if (percentage <= 0) {
                    return;
                }
            }
            this._progressBarAnimation = requestAnimationFrame(frame);
        };
        this._progressBarAnimation = requestAnimationFrame(frame);
    }
    ngOnDestroy() {
        var _a, _b;
        // Cancel animation
        if (this._progressBarAnimation) {
            cancelAnimationFrame(this._progressBarAnimation);
            this._progressBarAnimation = undefined;
        }
        // Clear auto close timeout
        this.clearTimerTimeout();
        // Complete all observables
        (_a = this.toast.$resetToast) === null || _a === void 0 ? void 0 : _a.complete();
        this.toast.$resetToast = null;
        (_b = this._$updateTimer) === null || _b === void 0 ? void 0 : _b.complete();
        this._$updateTimer = null;
    }
    startCloseTimer() {
        if (this.running || !this.autoCloseAfterSpecificChange()) {
            return;
        }
        this.running = true;
        this.expectedAutoDismissTime =
            new Date().getTime() + this.autoCloseRemaining;
        this.autoDismissTimeout = this._zone.runOutsideAngular(() => setTimeout(() => {
            this._zone.run(() => {
                this.dismissEvent.emit();
                this._cd.markForCheck();
            });
        }, this.autoCloseRemaining));
    }
    autoCloseAfterSpecificChange() {
        const specificAmount = (() => {
            switch (this.toast.type) {
                case ToastType.success:
                    return this.autoCloseSuccess;
                case ToastType.error:
                    return this.autoCloseError;
                case ToastType.warning:
                    return this.autoCloseWarn;
                case ToastType.info:
                    return this.autoCloseInfo;
                default:
                    return undefined;
            }
        })();
        return specificAmount === undefined ? this.autoClose : specificAmount;
    }
    pauseCloseTimer() {
        this.running = false;
        this.clearTimerTimeout();
        // Calculate the elapsed time, subtract remaining time
        this.pauseTime = new Date().getTime();
        const elapsed = this.pauseTime - this.startTime;
        this.autoCloseRemaining = this.autoCloseAfterSpecificChange() - elapsed;
    }
    resetToastTimer() {
        this.clearTimerTimeout();
        this.running = false;
        this.startTime = new Date().getTime();
        this.autoCloseRemaining = this.autoCloseAfterSpecificChange();
        this.startCloseTimer();
    }
    clearTimerTimeout() {
        if (this.autoDismissTimeout !== undefined) {
            this.expectedAutoDismissTime = undefined;
            clearTimeout(this.autoDismissTimeout);
        }
    }
    handleDismissButtonAction() {
        if (this.closeOnClick) {
            return; // Let the other event handle the dismissal
        }
        this.clearTimerTimeout();
        this.dismissEvent.emit();
    }
    handleHostClick() {
        if (this.closeOnClick) {
            this.clearTimerTimeout();
            this.dismissEvent.emit();
        }
    }
    handleMouseEnter() {
        if (this.pauseOnHover) {
            this.pauseCloseTimer();
        }
    }
    handleMouseLeave() {
        if (this.pauseOnHover) {
            this.startCloseTimer();
            this.startTime = new Date().getTime() + (this.startTime - this.pauseTime);
        }
    }
    handleVisibilityChange() {
        if (!this.pauseOnVisibilityChange) {
            return;
        }
        if (document.visibilityState !== 'visible') {
            this.pauseCloseTimer();
            this._cd.detectChanges();
        }
        else {
            this.startCloseTimer();
        }
    }
}
/** @nocollapse */ ToastifyToastComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.0.5", ngImport: i0, type: ToastifyToastComponent, deps: [{ token: i0.ChangeDetectorRef }, { token: i0.NgZone }], target: i0.ɵɵFactoryTarget.Component });
/** @nocollapse */ ToastifyToastComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.0.5", type: ToastifyToastComponent, selector: "lib-toastify-toast", inputs: { autoClose: "autoClose", autoCloseError: "autoCloseError", autoCloseSuccess: "autoCloseSuccess", autoCloseInfo: "autoCloseInfo", autoCloseWarn: "autoCloseWarn", hideProgressBar: "hideProgressBar", pauseOnHover: "pauseOnHover", pauseOnVisibilityChange: "pauseOnVisibilityChange", closeOnClick: "closeOnClick", toast: "toast", iconLibrary: "iconLibrary" }, outputs: { dismissEvent: "dismissEvent" }, host: { listeners: { "click": "handleHostClick()", "mouseenter": "handleMouseEnter()", "mouseleave": "handleMouseLeave()", "document:visibilitychange": "handleVisibilityChange()" } }, viewQueries: [{ propertyName: "progressBar", first: true, predicate: ["progressBar"], descendants: true }, { propertyName: "progressBarCover", first: true, predicate: ["progressBarCover"], descendants: true }], ngImport: i0, template: "<div role=\"alert\" class=\"angular-toastify-toast-body\">\n  <div class=\"angular-toastify-icon-container\">\n        <span *ngIf=\"iconLibrary == 'material'\" [ngSwitch]=\"toast.type\">\n            <i class=\"angular-toastify-toast-icon\" *ngSwitchCase=\"ToastType.info\">\n                <svg xmlns=\"http://www.w3.org/2000/svg\" height=\"20px\" viewBox=\"0 -960 960 960\" width=\"20px\"\n                     fill=\"#fff\"><path\n                  d=\"M430.09-270.8h101.34V-528H430.09v257.2Zm49.52-338.03q20.94 0 35.34-14.01 14.4-14.01 14.4-34.95 0-20.94-14.01-35.34-14.01-14.39-34.95-14.39-20.94 0-35.34 14.01-14.4 14.01-14.4 34.95 0 20.94 14.01 35.34 14.01 14.39 34.95 14.39Zm.67 548.18q-86.64 0-163.19-32.66-76.56-32.66-133.84-89.94t-89.94-133.8q-32.66-76.51-32.66-163.41 0-87.15 32.72-163.31t90.14-133.61q57.42-57.44 133.79-89.7 76.38-32.27 163.16-32.27 87.14 0 163.31 32.26 76.16 32.26 133.61 89.71 57.45 57.45 89.71 133.86 32.26 76.42 32.26 163.33 0 86.91-32.27 163.08-32.26 76.18-89.7 133.6-57.45 57.42-133.83 90.14-76.39 32.72-163.27 32.72Zm-.33-105.18q131.13 0 222.68-91.49 91.54-91.49 91.54-222.63 0-131.13-91.49-222.68-91.49-91.54-222.63-91.54-131.13 0-222.68 91.49-91.54 91.49-91.54 222.63 0 131.13 91.49 222.68 91.49 91.54 222.63 91.54ZM480-480Z\"/></svg>\n            </i>\n            <i class=\"angular-toastify-toast-icon\" *ngSwitchCase=\"ToastType.default\">\n                <svg xmlns=\"http://www.w3.org/2000/svg\" height=\"20px\" viewBox=\"0 -960 960 960\" width=\"20px\"\n                     fill=\"#aaa\"><path\n                  d=\"M430.09-270.8h101.34V-528H430.09v257.2Zm49.52-338.03q20.94 0 35.34-14.01 14.4-14.01 14.4-34.95 0-20.94-14.01-35.34-14.01-14.39-34.95-14.39-20.94 0-35.34 14.01-14.4 14.01-14.4 34.95 0 20.94 14.01 35.34 14.01 14.39 34.95 14.39Zm.67 548.18q-86.64 0-163.19-32.66-76.56-32.66-133.84-89.94t-89.94-133.8q-32.66-76.51-32.66-163.41 0-87.15 32.72-163.31t90.14-133.61q57.42-57.44 133.79-89.7 76.38-32.27 163.16-32.27 87.14 0 163.31 32.26 76.16 32.26 133.61 89.71 57.45 57.45 89.71 133.86 32.26 76.42 32.26 163.33 0 86.91-32.27 163.08-32.26 76.18-89.7 133.6-57.45 57.42-133.83 90.14-76.39 32.72-163.27 32.72Zm-.33-105.18q131.13 0 222.68-91.49 91.54-91.49 91.54-222.63 0-131.13-91.49-222.68-91.49-91.54-222.63-91.54-131.13 0-222.68 91.49-91.54 91.49-91.54 222.63 0 131.13 91.49 222.68 91.49 91.54 222.63 91.54ZM480-480Z\"/></svg>\n            </i>\n            <i class=\"angular-toastify-toast-icon\" *ngSwitchCase=\"ToastType.warning\">\n                  <svg xmlns=\"http://www.w3.org/2000/svg\" height=\"20px\" viewBox=\"0 -960 960 960\" width=\"20px\" fill=\"#fff\"><path d=\"M-3.28-104.15 480-911.43l483.28 807.28H-3.28Zm483.83-137.63q19.97 0 34.23-14.05 14.26-14.05 14.26-34.02 0-19.74-14.05-34-14.05-14.26-34.02-14.26-19.73 0-34.11 14.05-14.38 14.05-14.38 33.78 0 19.98 14.17 34.24 14.17 14.26 33.9 14.26Zm-46.88-138.7h94.18v-192.89h-94.18v192.89Z\"/></svg>\n            </i>\n            <i class=\"angular-toastify-toast-icon\" *ngSwitchCase=\"ToastType.error\">\n                  <svg xmlns=\"http://www.w3.org/2000/svg\" height=\"20px\" viewBox=\"0 -960 960 960\" width=\"20px\" fill=\"#fff\"><path d=\"M479.56-266.26q21.83 0 36.89-14.61 15.05-14.62 15.05-36.45 0-21.83-14.61-37.01-14.62-15.17-36.45-15.17-21.83 0-36.89 14.79-15.05 14.79-15.05 36.62t14.61 36.83q14.62 15 36.45 15Zm-51.39-167.02h105.18v-250.55H428.17v250.55Zm52.11 372.63q-86.64 0-163.19-32.66-76.56-32.66-133.84-89.94t-89.94-133.8q-32.66-76.51-32.66-163.41 0-87.15 32.72-163.31t90.14-133.61q57.42-57.44 133.79-89.7 76.38-32.27 163.16-32.27 87.14 0 163.31 32.26 76.16 32.26 133.61 89.71 57.45 57.45 89.71 133.86 32.26 76.42 32.26 163.33 0 86.91-32.27 163.08-32.26 76.18-89.7 133.6-57.45 57.42-133.83 90.14-76.39 32.72-163.27 32.72Zm-.33-105.18q131.13 0 222.68-91.49 91.54-91.49 91.54-222.63 0-131.13-91.49-222.68-91.49-91.54-222.63-91.54-131.13 0-222.68 91.49-91.54 91.49-91.54 222.63 0 131.13 91.49 222.68 91.49 91.54 222.63 91.54ZM480-480Z\"/></svg>\n            </i>\n            <i class=\"angular-toastify-toast-icon\" *ngSwitchCase=\"ToastType.success\">\n                  <svg xmlns=\"http://www.w3.org/2000/svg\" height=\"20px\" viewBox=\"0 -960 960 960\" width=\"20px\" fill=\"#fff\"><path d=\"M389-240.7 166.93-461.76l74.27-75.26L389-388.98l331.57-330.56 74.26 74.02L389-240.7Z\"/></svg>\n            </i>\n        </span>\n    <span *ngIf=\"iconLibrary == 'font-awesome'\" [ngSwitch]=\"toast.type\">\n            <i *ngSwitchCase=\"ToastType.info\" class=\"angular-toastify-toast-icon\">\n              <svg xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 192 512\" height=\"18\" fill=\"#fff\">>\n                <!--!Font Awesome Free 6.6.0 by @fontawesome - https://fontawesome.com License - https://fontawesome.com/license/free Copyright 2024 Fonticons, Inc.-->\n                <path d=\"M48 80a48 48 0 1 1 96 0A48 48 0 1 1 48 80zM0 224c0-17.7 14.3-32 32-32l64 0c17.7 0 32 14.3 32 32l0 224 32 0c17.7 0 32 14.3 32 32s-14.3 32-32 32L32 512c-17.7 0-32-14.3-32-32s14.3-32 32-32l32 0 0-192-32 0c-17.7 0-32-14.3-32-32z\"/>\n              </svg>\n            </i>\n            <i *ngSwitchCase=\"ToastType.default\" class=\"angular-toastify-toast-icon\">\n              <svg xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 192 512\" height=\"18\" fill=\"#aaa\">>\n                <!--!Font Awesome Free 6.6.0 by @fontawesome - https://fontawesome.com License - https://fontawesome.com/license/free Copyright 2024 Fonticons, Inc.-->\n                <path d=\"M48 80a48 48 0 1 1 96 0A48 48 0 1 1 48 80zM0 224c0-17.7 14.3-32 32-32l64 0c17.7 0 32 14.3 32 32l0 224 32 0c17.7 0 32 14.3 32 32s-14.3 32-32 32L32 512c-17.7 0-32-14.3-32-32s14.3-32 32-32l32 0 0-192-32 0c-17.7 0-32-14.3-32-32z\"/>\n              </svg>\n            </i>\n            <i *ngSwitchCase=\"ToastType.warning\" class=\"angular-toastify-toast-icon\">\n              <svg xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 512 512\" height=\"18\" fill=\"#fff\">>\n                <!--!Font Awesome Free 6.6.0 by @fontawesome - https://fontawesome.com License - https://fontawesome.com/license/free Copyright 2024 Fonticons, Inc.-->\n                <path d=\"M256 32c14.2 0 27.3 7.5 34.5 19.8l216 368c7.3 12.4 7.3 27.7 .2 40.1S486.3 480 472 480L40 480c-14.3 0-27.6-7.7-34.7-20.1s-7-27.8 .2-40.1l216-368C228.7 39.5 241.8 32 256 32zm0 128c-13.3 0-24 10.7-24 24l0 112c0 13.3 10.7 24 24 24s24-10.7 24-24l0-112c0-13.3-10.7-24-24-24zm32 224a32 32 0 1 0 -64 0 32 32 0 1 0 64 0z\"/>\n              </svg>\n            </i>\n            <i *ngSwitchCase=\"ToastType.error\" class=\"angular-toastify-toast-icon\">\n              <svg xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 128 512\" height=\"18\" fill=\"#fff\">\n                <!--!Font Awesome Free 6.6.0 by @fontawesome - https://fontawesome.com License - https://fontawesome.com/license/free Copyright 2024 Fonticons, Inc.-->\n                <path d=\"M96 64c0-17.7-14.3-32-32-32S32 46.3 32 64l0 256c0 17.7 14.3 32 32 32s32-14.3 32-32L96 64zM64 480a40 40 0 1 0 0-80 40 40 0 1 0 0 80z\"/>\n              </svg>\n            </i>\n            <i *ngSwitchCase=\"ToastType.success\" class=\"angular-toastify-toast-icon\">\n              <svg xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 448 512\" height=\"18\" fill=\"#fff\">>\n                <!--!Font Awesome Free 6.6.0 by @fontawesome - https://fontawesome.com License - https://fontawesome.com/license/free Copyright 2024 Fonticons, Inc.-->\n                <path d=\"M438.6 105.4c12.5 12.5 12.5 32.8 0 45.3l-256 256c-12.5 12.5-32.8 12.5-45.3 0l-128-128c-12.5-12.5-12.5-32.8 0-45.3s32.8-12.5 45.3 0L160 338.7 393.4 105.4c12.5-12.5 32.8-12.5 45.3 0z\"/>\n              </svg>\n            </i>\n        </span>\n  </div>\n  <div class=\"angular-toastify-toast-container\">\n    <div>{{ toast.message }}</div>\n  </div>\n  <div class=\"close-container\">\n    <button (click)=\"handleDismissButtonAction()\"\n            class=\"angular-toastify-close-button angular-toastify-close-button--{{ToastType[toast.type]}}\" type=\"button\"\n            aria-label=\"close\">\u2716\n    </button>\n  </div>\n</div>\n\n<div #progressBar *ngIf=\"!hideProgressBar\"\n     class=\"angular-toastify-progress-bar angular-toastify-progress-bar&#45;&#45;{{ToastType[toast.type]}}\"\n     style=\"opacity: 1;\"></div>\n<div #progressBarCover *ngIf=\"!hideProgressBar\"\n     class=\"angular-toastify-progress-bar-cover angular-toastify-toast--{{ToastType[toast.type]}}\"\n     [style.animation-duration]=\"this.autoCloseAfterSpecificChange() + 'ms'\"\n     [style.animation-play-state]=\"running? 'running' : 'paused'\"></div>\n", styles: [".angular-toastify-toast{position:relative;min-height:64px;box-sizing:border-box;margin-bottom:1rem;padding:8px;border-radius:1px;box-shadow:0 1px 10px 0 rgba(0,0,0,.1),0 2px 15px 0 rgba(0,0,0,.05);display:flex;justify-content:space-between;max-height:800px;overflow:hidden;font-family:sans-serif;cursor:pointer;direction:ltr}.angular-toastify-toast--rtl{direction:rtl}.angular-toastify-toast--default{background:#fff;color:#aaa}.angular-toastify-toast--info{background:#3498db}.angular-toastify-toast--success{background:#07bc0c}.angular-toastify-toast--warning{background:#f1c40f}.angular-toastify-toast--error{background:#e74c3c}.angular-toastify-toast-body{margin:auto 0;flex:1}@media only screen and (max-width:480px){.angular-toastify-toast{margin-bottom:0}}.angular-toastify-close-button{color:#fff;font-weight:700;font-size:14px;background:transparent;outline:none;border:none;padding:0;cursor:pointer;opacity:.7;transition:.3s ease;align-self:flex-start}.angular-toastify-close-button--default{color:#000;opacity:.3}.angular-toastify-close-button:focus,.angular-toastify-close-button:hover{opacity:1}.angular-toastify-progress-bar-cover{right:0;z-index:100;direction:rtl}.angular-toastify-progress-bar,.angular-toastify-progress-bar-cover{position:absolute;bottom:0;width:100%;height:5px;transform-origin:left}.angular-toastify-progress-bar{left:0;z-index:99;opacity:.7;background-color:hsla(0,0%,100%,.7)}.angular-toastify-progress-bar--controlled{transition:transform .2s}.angular-toastify-progress-bar--rtl{right:0;left:auto;transform-origin:right}.angular-toastify-progress-bar--default{background:linear-gradient(90deg,#4cd964,#5ac8fa,#007aff,#34aadc,#5856d6,#ff2d55)}.angular-toastify-toast-body{min-width:0;min-height:0;vertical-align:middle;display:flex}.angular-toastify-icon-container{display:flex;flex-direction:column;justify-content:center;width:25px;vertical-align:middle}.angular-toastify-icon-container span{margin-right:.5rem;display:inline-block;text-align:center;width:20px}.angular-toastify-icon-container span i{vertical-align:middle}.angular-toastify-toast-icon{display:flex;flex-direction:column;justify-content:center;align-items:center;font-size:18px}.angular-toastify-toast-container{width:calc(100% - 25px);overflow-y:auto;display:flex;flex-direction:column;min-height:0}.angular-toastify-toast-container>div{display:flex;flex:1;flex-direction:column;justify-content:center}"], directives: [{ type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { type: i1.NgSwitch, selector: "[ngSwitch]", inputs: ["ngSwitch"] }, { type: i1.NgSwitchCase, selector: "[ngSwitchCase]", inputs: ["ngSwitchCase"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.0.5", ngImport: i0, type: ToastifyToastComponent, decorators: [{
            type: Component,
            args: [{
                    // tslint:disable-next-line:component-selector
                    selector: 'lib-toastify-toast',
                    templateUrl: './toastify-toast.component.html',
                    styleUrls: ['./toastify-toast.component.scss'],
                    // changeDetection: ChangeDetectionStrategy.OnPush
                }]
        }], ctorParameters: function () { return [{ type: i0.ChangeDetectorRef }, { type: i0.NgZone }]; }, propDecorators: { progressBar: [{
                type: ViewChild,
                args: ['progressBar']
            }], progressBarCover: [{
                type: ViewChild,
                args: ['progressBarCover']
            }], autoClose: [{
                type: Input
            }], autoCloseError: [{
                type: Input
            }], autoCloseSuccess: [{
                type: Input
            }], autoCloseInfo: [{
                type: Input
            }], autoCloseWarn: [{
                type: Input
            }], hideProgressBar: [{
                type: Input
            }], pauseOnHover: [{
                type: Input
            }], pauseOnVisibilityChange: [{
                type: Input
            }], closeOnClick: [{
                type: Input
            }], toast: [{
                type: Input
            }], iconLibrary: [{
                type: Input
            }], dismissEvent: [{
                type: Output
            }], handleHostClick: [{
                type: HostListener,
                args: ['click']
            }], handleMouseEnter: [{
                type: HostListener,
                args: ['mouseenter']
            }], handleMouseLeave: [{
                type: HostListener,
                args: ['mouseleave']
            }], handleVisibilityChange: [{
                type: HostListener,
                args: ['document:visibilitychange']
            }] } });

class ToastifyToastContainerComponent {
    constructor(_toastService, _cd) {
        this._toastService = _toastService;
        this._cd = _cd;
        this.transitionDurations = 400;
        this.position = 'top-right';
        this.transition = 'bounce';
        this.autoClose = 5000;
        this.autoCloseError = undefined;
        this.autoCloseSuccess = undefined;
        this.autoCloseInfo = undefined;
        this.autoCloseWarn = undefined;
        this.hideProgressBar = false;
        this.pauseOnHover = true;
        this.pauseOnVisibilityChange = true;
        this.closeOnClick = true;
        this.newestOnTop = false;
        this.preventDuplicates = false;
        this.iconLibrary = 'none';
        this.ToastType = ToastType;
        this.toasts = new Array();
        this.toastTransitionDict = {};
    }
    ngOnChanges() {
        this._cd.markForCheck();
    }
    dismiss(toast) {
        this.toastTransitionDict[toast.id] = TransitionState.exiting;
        setTimeout(() => {
            const index = this.toasts.indexOf(toast);
            this.toasts.splice(index, 1);
            this._cd.markForCheck();
        }, this.transitionDurations);
    }
    getClass(toast) {
        let base = `angular-toastify-toast angular-toastify-toast--${ToastType[toast.type]} `;
        const state = this.toastTransitionDict[toast.id];
        if (state === TransitionState.entering) {
            base += `angular-toastify-${this.transition}-enter angular-toastify-${this.transition}-enter--${this.position}`;
        }
        else if (state === TransitionState.exiting) {
            base += `angular-toastify-${this.transition}-exit angular-toastify-${this.transition}-exit--${this.position}`;
        }
        return base;
    }
    ngOnInit() {
        this._toastService.dismissAllEvent.subscribe(() => {
            this.toasts = new Array();
            this._cd.markForCheck();
        });
        this._toastService.toastAddedEvent.subscribe((toast) => this.handleToastAddedEvent(toast));
    }
    handleToastAddedEvent(toast) {
        // If "preventDuplicates" is enabled, toast is not added if one toast with same message exists
        // The only thing to do is to update the toast time to keep it visible
        if (this.preventDuplicates === true) {
            const sameToast = this.toasts.find((existingToast) => existingToast.message === toast.message);
            if (sameToast) {
                sameToast.$resetToast.next();
                this._cd.markForCheck();
                return;
            }
        }
        // Add new toast transition
        this.toastTransitionDict[toast.id] = TransitionState.entering;
        setTimeout(() => {
            this.toastTransitionDict[toast.id] = TransitionState.noTransition;
            this._cd.markForCheck();
        }, this.transitionDurations);
        // Add new toast
        if (this.newestOnTop) {
            this.toasts.unshift(toast);
        }
        else {
            this.toasts.push(toast);
        }
        this._cd.markForCheck();
    }
}
/** @nocollapse */ ToastifyToastContainerComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.0.5", ngImport: i0, type: ToastifyToastContainerComponent, deps: [{ token: ToastService }, { token: i0.ChangeDetectorRef }], target: i0.ɵɵFactoryTarget.Component });
/** @nocollapse */ ToastifyToastContainerComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.0.5", type: ToastifyToastContainerComponent, selector: "lib-toastify-toast-container", inputs: { position: "position", transition: "transition", autoClose: "autoClose", autoCloseError: "autoCloseError", autoCloseSuccess: "autoCloseSuccess", autoCloseInfo: "autoCloseInfo", autoCloseWarn: "autoCloseWarn", hideProgressBar: "hideProgressBar", pauseOnHover: "pauseOnHover", pauseOnVisibilityChange: "pauseOnVisibilityChange", closeOnClick: "closeOnClick", newestOnTop: "newestOnTop", preventDuplicates: "preventDuplicates", iconLibrary: "iconLibrary" }, usesOnChanges: true, ngImport: i0, template: "<div class=\"angular-toastify-toast-container angular-toastify-toast-container--{{position}}\">\n    <lib-toastify-toast *ngFor=\"let toast of toasts\" [class]=\"getClass(toast)\" style=\"animation-fill-mode: both; animation-duration: 0.75s; flex-direction: column;\"\n        [autoClose]=\"autoClose\" [autoCloseSuccess]=\"this.autoCloseSuccess\" [autoCloseError]=\"this.autoCloseError\" [autoCloseWarn]=\"this.autoCloseWarn\"\n        [autoCloseInfo]=\"this.autoCloseInfo\" [toast]=\"toast\" (dismissEvent)=\"dismiss(toast)\" [hideProgressBar]=\"hideProgressBar\" [pauseOnHover]=\"pauseOnHover\"\n        [pauseOnVisibilityChange]=\"pauseOnVisibilityChange\" [closeOnClick]=\"closeOnClick\" [iconLibrary]=\"iconLibrary\">\n    </lib-toastify-toast>\n</div>\n", styles: [".angular-toastify-toast-container{word-break:break-word;z-index:9999;-webkit-transform:translateZ(9999px);position:fixed;padding:4px;width:320px;box-sizing:border-box;color:#fff}.angular-toastify-toast-container--top-left{top:1em;left:1em}.angular-toastify-toast-container--top-center{top:1em;left:50%;margin-left:-160px}.angular-toastify-toast-container--top-right{top:1em;right:1em}.angular-toastify-toast-container--bottom-left{bottom:1em;left:1em}.angular-toastify-toast-container--bottom-center{bottom:1em;left:50%;margin-left:-160px}.angular-toastify-toast-container--bottom-right{bottom:1em;right:1em}@media only screen and (max-width:480px){.angular-toastify-toast-container{width:100vw;padding:0;left:0;margin:0}.angular-toastify-toast-container--top-center,.angular-toastify-toast-container--top-left,.angular-toastify-toast-container--top-right{top:0}.angular-toastify-toast-container--bottom-center,.angular-toastify-toast-container--bottom-left,.angular-toastify-toast-container--bottom-right{bottom:0}.angular-toastify-toast-container--rtl{right:0;left:auto}}.angular-toastify-toast{position:relative;min-height:64px;box-sizing:border-box;margin-bottom:1rem;padding:8px;border-radius:1px;box-shadow:0 1px 10px 0 rgba(0,0,0,.1),0 2px 15px 0 rgba(0,0,0,.05);display:flex;justify-content:space-between;max-height:800px;overflow:hidden;font-family:sans-serif;cursor:pointer;direction:ltr}.angular-toastify-toast--rtl{direction:rtl}.angular-toastify-toast--default{background:#fff;color:#aaa}.angular-toastify-toast--info{background:#3498db}.angular-toastify-toast--success{background:#07bc0c}.angular-toastify-toast--warning{background:#f1c40f}.angular-toastify-toast--error{background:#e74c3c}.angular-toastify-toast-body{margin:auto 0;flex:1}@media only screen and (max-width:480px){.angular-toastify-toast{margin-bottom:0}}@keyframes angular-toastify-bounceInRight{0%,60%,75%,90%,to{animation-timing-function:cubic-bezier(.215,.61,.355,1)}0%{opacity:0;transform:translate3d(3000px,0,0)}60%{opacity:1;transform:translate3d(-25px,0,0)}75%{transform:translate3d(10px,0,0)}90%{transform:translate3d(-5px,0,0)}to{transform:none}}@keyframes angular-toastify-bounceOutRight{20%{opacity:1;transform:translate3d(-20px,0,0)}to{opacity:0;transform:translate3d(2000px,0,0)}}@keyframes angular-toastify-bounceInLeft{0%,60%,75%,90%,to{animation-timing-function:cubic-bezier(.215,.61,.355,1)}0%{opacity:0;transform:translate3d(-3000px,0,0)}60%{opacity:1;transform:translate3d(25px,0,0)}75%{transform:translate3d(-10px,0,0)}90%{transform:translate3d(5px,0,0)}to{transform:none}}@keyframes angular-toastify-bounceOutLeft{20%{opacity:1;transform:translate3d(20px,0,0)}to{opacity:0;transform:translate3d(-2000px,0,0)}}@keyframes angular-toastify-bounceInUp{0%,60%,75%,90%,to{animation-timing-function:cubic-bezier(.215,.61,.355,1)}0%{opacity:0;transform:translate3d(0,3000px,0)}60%{opacity:1;transform:translate3d(0,-20px,0)}75%{transform:translate3d(0,10px,0)}90%{transform:translate3d(0,-5px,0)}to{transform:translateZ(0)}}@keyframes angular-toastify-bounceOutUp{20%{transform:translate3d(0,-10px,0)}40%,45%{opacity:1;transform:translate3d(0,20px,0)}to{opacity:0;transform:translate3d(0,-2000px,0)}}@keyframes angular-toastify-bounceInDown{0%,60%,75%,90%,to{animation-timing-function:cubic-bezier(.215,.61,.355,1)}0%{opacity:0;transform:translate3d(0,-3000px,0)}60%{opacity:1;transform:translate3d(0,25px,0)}75%{transform:translate3d(0,-10px,0)}90%{transform:translate3d(0,5px,0)}to{transform:none}}@keyframes angular-toastify-bounceOutDown{20%{transform:translate3d(0,10px,0)}40%,45%{opacity:1;transform:translate3d(0,-20px,0)}to{opacity:0;transform:translate3d(0,2000px,0)}}.angular-toastify-bounce-enter--bottom-left,.angular-toastify-bounce-enter--top-left{animation-name:angular-toastify-bounceInLeft}.angular-toastify-bounce-enter--bottom-right,.angular-toastify-bounce-enter--top-right{animation-name:angular-toastify-bounceInRight}.angular-toastify-bounce-enter--top-center{animation-name:angular-toastify-bounceInDown}.angular-toastify-bounce-enter--bottom-center{animation-name:angular-toastify-bounceInUp}.angular-toastify-bounce-exit--bottom-left,.angular-toastify-bounce-exit--top-left{animation-name:angular-toastify-bounceOutLeft}.angular-toastify-bounce-exit--bottom-right,.angular-toastify-bounce-exit--top-right{animation-name:angular-toastify-bounceOutRight}.angular-toastify-bounce-exit--top-center{animation-name:angular-toastify-bounceOutUp}.angular-toastify-bounce-exit--bottom-center{animation-name:angular-toastify-bounceOutDown}@keyframes angular-toastify-zoomIn{0%{opacity:0;transform:scale3d(.3,.3,.3)}50%{opacity:1}}@keyframes angular-toastify-zoomOut{0%{opacity:1}50%{opacity:0;transform:scale3d(.3,.3,.3)}to{opacity:0}}.angular-toastify-zoom-enter{animation-name:angular-toastify-zoomIn}.angular-toastify-zoom-exit{animation-name:angular-toastify-zoomOut}@keyframes angular-toastify-flipIn{0%{transform:perspective(400px) rotateX(90deg);animation-timing-function:ease-in;opacity:0}40%{transform:perspective(400px) rotateX(-20deg);animation-timing-function:ease-in}60%{transform:perspective(400px) rotateX(10deg);opacity:1}80%{transform:perspective(400px) rotateX(-5deg)}to{transform:perspective(400px)}}@keyframes angular-toastify-flipOut{0%{transform:perspective(400px)}30%{transform:perspective(400px) rotateX(-20deg);opacity:1}to{transform:perspective(400px) rotateX(90deg);opacity:0}}.angular-toastify-flip-enter{animation-name:angular-toastify-flipIn}.angular-toastify-flip-exit{animation-name:angular-toastify-flipOut}@keyframes angular-toastify-slideInRight{0%{transform:translate3d(110%,0,0);visibility:visible}to{transform:translateZ(0)}}@keyframes angular-toastify-slideInLeft{0%{transform:translate3d(-110%,0,0);visibility:visible}to{transform:translateZ(0)}}@keyframes angular-toastify-slideInUp{0%{transform:translate3d(0,110%,0);visibility:visible}to{transform:translateZ(0)}}@keyframes angular-toastify-slideInDown{0%{transform:translate3d(0,-110%,0);visibility:visible}to{transform:translateZ(0)}}@keyframes angular-toastify-slideOutRight{0%{transform:translateZ(0)}to{visibility:hidden;transform:translate3d(110%,0,0)}}@keyframes angular-toastify-slideOutLeft{0%{transform:translateZ(0)}to{visibility:hidden;transform:translate3d(-110%,0,0)}}@keyframes angular-toastify-slideOutDown{0%{transform:translateZ(0)}to{visibility:hidden;transform:translate3d(0,500px,0)}}@keyframes angular-toastify-slideOutUp{0%{transform:translateZ(0)}to{visibility:hidden;transform:translate3d(0,-500px,0)}}.angular-toastify-slide-enter--bottom-left,.angular-toastify-slide-enter--top-left{animation-name:angular-toastify-slideInLeft}.angular-toastify-slide-enter--bottom-right,.angular-toastify-slide-enter--top-right{animation-name:angular-toastify-slideInRight}.angular-toastify-slide-enter--top-center{animation-name:angular-toastify-slideInDown}.angular-toastify-slide-enter--bottom-center{animation-name:angular-toastify-slideInUp}.angular-toastify-slide-exit--bottom-left,.angular-toastify-slide-exit--top-left{animation-name:angular-toastify-slideOutLeft}.angular-toastify-slide-exit--bottom-right,.angular-toastify-slide-exit--top-right{animation-name:angular-toastify-slideOutRight}.angular-toastify-slide-exit--top-center{animation-name:angular-toastify-slideOutUp}.angular-toastify-slide-exit--bottom-center{animation-name:angular-toastify-slideOutDown}"], components: [{ type: ToastifyToastComponent, selector: "lib-toastify-toast", inputs: ["autoClose", "autoCloseError", "autoCloseSuccess", "autoCloseInfo", "autoCloseWarn", "hideProgressBar", "pauseOnHover", "pauseOnVisibilityChange", "closeOnClick", "toast", "iconLibrary"], outputs: ["dismissEvent"] }], directives: [{ type: i1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.0.5", ngImport: i0, type: ToastifyToastContainerComponent, decorators: [{
            type: Component,
            args: [{
                    // tslint:disable-next-line:component-selector
                    selector: 'lib-toastify-toast-container',
                    templateUrl: './toastify-toast-container.component.html',
                    styleUrls: ['./toastify-toast-container.component.scss'],
                    changeDetection: ChangeDetectionStrategy.OnPush,
                }]
        }], ctorParameters: function () { return [{ type: ToastService }, { type: i0.ChangeDetectorRef }]; }, propDecorators: { position: [{
                type: Input
            }], transition: [{
                type: Input
            }], autoClose: [{
                type: Input
            }], autoCloseError: [{
                type: Input
            }], autoCloseSuccess: [{
                type: Input
            }], autoCloseInfo: [{
                type: Input
            }], autoCloseWarn: [{
                type: Input
            }], hideProgressBar: [{
                type: Input
            }], pauseOnHover: [{
                type: Input
            }], pauseOnVisibilityChange: [{
                type: Input
            }], closeOnClick: [{
                type: Input
            }], newestOnTop: [{
                type: Input
            }], preventDuplicates: [{
                type: Input
            }], iconLibrary: [{
                type: Input
            }] } });
var TransitionState;
(function (TransitionState) {
    TransitionState[TransitionState["entering"] = 0] = "entering";
    TransitionState[TransitionState["noTransition"] = 1] = "noTransition";
    TransitionState[TransitionState["exiting"] = 2] = "exiting";
})(TransitionState || (TransitionState = {}));

class AngularToastifyModule {
}
/** @nocollapse */ AngularToastifyModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.0.5", ngImport: i0, type: AngularToastifyModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
/** @nocollapse */ AngularToastifyModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "12.0.5", ngImport: i0, type: AngularToastifyModule, declarations: [ToastifyToastComponent, ToastifyToastContainerComponent], imports: [CommonModule], exports: [ToastifyToastContainerComponent] });
/** @nocollapse */ AngularToastifyModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "12.0.5", ngImport: i0, type: AngularToastifyModule, imports: [[CommonModule]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.0.5", ngImport: i0, type: AngularToastifyModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [ToastifyToastComponent, ToastifyToastContainerComponent],
                    imports: [CommonModule],
                    exports: [ToastifyToastContainerComponent]
                }]
        }] });

/*
 * Public API Surface of angular-toastify
 */

/**
 * Generated bundle index. Do not edit.
 */

export { AngularToastifyModule, ToastService, ToastifyToastContainerComponent };
//# sourceMappingURL=angular-toastify.js.map
